==> mysql-5.6.51.tar.gz: mysql-5.6.51/storage/ndb/clusterj/clusterj-openjpa/src/test/java/com/mysql/clusterj/openjpatest/TestBadPersistenceUnitNoConnectString.java <==
/*
 *  Copyright 2010 Sun Microsystems, Inc.
 *   All rights reserved. Use is subject to license terms.
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2.0,
 *  as published by the Free Software Foundation.
 *
 *  This program is also distributed with certain software (including
 *  but not limited to OpenSSL) that is licensed under separate terms,
 *  as designated in a particular file or component or in included license
 *  documentation.  The authors of MySQL hereby grant you an additional
 *  permission to link the program and your derivative works with the
 *  separately licensed software that they have included with MySQL.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License, version 2.0, for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.clusterj.openjpatest;

import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import junit.framework.TestCase;

/**
 *
 */
public class TestBadPersistenceUnitNoConnectString extends TestCase {

    protected String getPersistenceUnitName() {
        return "BadPUNoConnectString";
    }
    public void test() {
        try {
            EntityManagerFactory emf = Persistence.createEntityManagerFactory(
                    getPersistenceUnitName());
            emf.createEntityManager();
            assertNull("Unexpected emf for null connectString", emf);
        } catch (RuntimeException ex) {
            // see if it has the connectString message
            if (!(ex.getMessage().contains("connectString"))) {
                fail("Wrong exception thrown. " +
                        "Expected Exception with connectString; got " +
                        ex.getMessage());
            }
        }
    }

}

==> mysql-5.7.28.tar.gz: mysql-5.7.28/storage/ndb/clusterj/clusterj-openjpa/src/test/java/com/mysql/clusterj/openjpatest/TestBadPersistenceUnitNoConnectString.java <==
/*
 *  Copyright 2010 Sun Microsystems, Inc.
 *   All rights reserved. Use is subject to license terms.
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2.0,
 *  as published by the Free Software Foundation.
 *
 *  This program is also distributed with certain software (including
 *  but not limited to OpenSSL) that is licensed under separate terms,
 *  as designated in a particular file or component or in included license
 *  documentation.  The authors of MySQL hereby grant you an additional
 *  permission to link the program and your derivative works with the
 *  separately licensed software that they have included with MySQL.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License, version 2.0, for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.clusterj.openjpatest;

import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import junit.framework.TestCase;

/**
 *
 */
public class TestBadPersistenceUnitNoConnectString extends TestCase {

    protected String getPersistenceUnitName() {
        return "BadPUNoConnectString";
    }
    public void test() {
        try {
            EntityManagerFactory emf = Persistence.createEntityManagerFactory(
                    getPersistenceUnitName());
            emf.createEntityManager();
            if(emf != null) {
                fail("Unexpected emf for null connectString");
            }
            
        } catch (RuntimeException ex) {
            // see if it has the connectString message
            if (!(ex.getMessage().contains("connectString"))) {
                fail("Wrong exception thrown. " +
                        "Expected Exception with connectString; got " +
                        ex.getMessage());
            }
        }
    }

}
